# Shell

A development shell for mitosis track / midbody detection.

Written in dash, not intended for deployment. Internal use only.
Should be used on user's computer.

## Extra dependencies
- dash
- dash-mantine-components
- dash-iconify